@@ -7,7 +7,7 @@ use warnings FATAL => 'all';
 ###########################################################################
 
 { package Muldis::D; # package
-    use version 0.74; our $VERSION = qv('0.49.0');
+    use version 0.74; our $VERSION = qv('0.50.0');
     # Note that Perl code only exists at all in this file in order to help
     # the CPAN indexer handle the distribution properly.
 } # package Muldis::D
@@ -29,7 +29,7 @@ Formal spec of Muldis D relational DBMS lang
 
 =head1 VERSION
 
-This document is Muldis::D version 0.49.0.
+This document is Muldis::D version 0.50.0.
 
 =head1 PREFACE
 
@@ -57,9 +57,9 @@ at them.
 
 The fully-qualified name of this multi-part document and the language
 specification it contains (as a single composition) is
-C<Muldis_D:'http://muldis.com':'0.49.0'>.  It is the official/original (not
+C<Muldis_D:'http://muldis.com':'0.50.0'>.  It is the official/original (not
 embraced and extended) Muldis D language specification by the authority
-Darren Duncan (C<http://muldis.com>), version C<0.49.0> (this number
+Darren Duncan (C<http://muldis.com>), version C<0.50.0> (this number
 matches the VERSION pod in this file).  This multi-part document is named
 and organized with the expectation that many dialects, extensions, and core
 versions of it will exist over time, some of those under the original
@@ -129,13 +129,20 @@ the original author and by other parties.
 
 At the highest level, a fully-qualified Muldis D language name is a
 (ordered) sequence of values having a minimum of 2 elements, and typically
-about 5 elements.  The elements are read one at a time, starting with the
+about 4-6 elements.  The elements are read one at a time, starting with the
 first; the value of each element, combined with those before it, determine
 what number and kind of elements are valid to follow it in the sequence.
 So all Muldis D variants are organized into a single hierarchy where each
 child node represents a language derived from or extending the language
 represented by its parent node.
 
+In documentation, it is typical to use a Muldis D language name involving
+just a sub-sequence of the allowed elements that is missing child-most
+allowed elements; in that case, this language name implicitly refers to the
+entire language sub-tree having the specified elements in common; an
+example of this is the 3-element name mentioned in this file's DESCRIPTION
+section.  Even in code, sometimes certain child-most elements are optional.
+
 =head2 Foundation
 
 The actual formatting of a "sequence" used as this language name is
@@ -258,16 +265,9 @@ L<Muldis::D::Dialect::HDMD_Perl_Tiny>.
 
 =head2 Extensions
 
-The fifth element of the Muldis D language name is an unordered collection
-of name+value pairs (the names are unique keys in the collection) and are
-for specifying any other information that should be known.  Some possible
-name+value pairs are dialect-specific pragmas or compiler directives, that
-change the behaviour of just how the dialect is parsed and are otherwise
-agnostic to implementation and have no further affect on code after it has
-been parsed.  Other possible name+value pairs will enumerate what various
-non-standard but implementation-provided built-in features the current
-Muldis D code makes use of; non-standard in this case meaning not part of
-the already named language authority+version+dialect.
+Whether or not the Muldis D language name has a fifth or further elements
+depends on the dialect.  See the documentation for each individual dialect
+to see what it supports or requires.
 
 =head1 SEE ALSO
 
